angular.module('tamkEvents', ['ionic', 'ngResource', 'ngCordova',
    'pascalprecht.translate'])

    .run(function ($ionicPlatform, $cordovaDevice, $resource, $rootScope,
                   $state) {

        $ionicPlatform.ready(function () {
            if (!localStorage.user) {
                var device = $cordovaDevice.getDevice();
                var result = $resource("http://tamkevents.com/api/public/user/");

                var root = result.save({
                    key: "paprika",
                    device: device.model,
                    manufacturer: device.manufacturer,
                    platform: device.platform,
                    uuid: device.uuid,
                    language: navigator.language
                }, function () {
                    localStorage.user = true;
                });
            }

            if (!localStorage.start) {
                $state.go("start");
            }

            // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
            // for form inputs)
            if (window.cordova && window.cordova.plugins.Keyboard) {
                cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
                cordova.plugins.Keyboard.disableScroll(true);
                window.open = cordova.InAppBrowser.open;
            }

            if (window.StatusBar) {
                console.log(cordova.platformId);
                if (cordova.platformId === "android") {
                    StatusBar.backgroundColorByHexString("#480224");
                } else {
                    StatusBar.styleLightContent();
                    StatusBar.overlaysWebView(true);
                }

                // org.apache.cordova.statusbar required
                //StatusBar.styleDefault();
                // StatusBar.backgroundColorByHexString("#37011d");
            }
        });
    })

    .config(function ($stateProvider, $urlRouterProvider, $translateProvider, $provide) {

        $stateProvider
            .state('app', {
                url: '/app',
                abstract: true,
                templateUrl: 'templates/menu.html',
                controller: 'AppCtrl'
            })

            .state('start', {
                url: '/start',
                controller: 'AppCtrl',
                templateUrl: 'templates/slider.html'
            })

            .state('app.upcoming', {
                url: '/events/upcoming',
                views: {
                    'upcoming': {
                        templateUrl: 'templates/upcoming.html',
                        controller: 'EventsCtrl'
                    }
                }
            })

            .state('app.upcomingevent', {
                url: '/events/upcomingevent/:id',
                views: {
                    'upcoming': {
                        templateUrl: 'templates/event.html',
                        controller: 'EventCtrl'
                    }
                }
            })

            .state('app.latest', {
                url: '/events/latest',
                views: {
                    'latest': {
                        templateUrl: 'templates/latest.html',
                        controller: 'EventsCtrl'
                    }
                }
            })

            .state('app.latestevent', {
                url: '/events/latestevent/:id',
                views: {
                    'latest': {
                        templateUrl: 'templates/event.html',
                        controller: 'EventCtrl'
                    }
                }
            })

            .state('app.favorites', {
                url: '/events/favorites',
                views: {
                    'favorites': {
                        templateUrl: 'templates/favorites.html',
                        controller: 'EventsCtrl'
                    }
                }
            })

            .state('app.favoritesevent', {
                url: 'events/favoritesevent/:id',
                views: {
                    'favorites': {
                        templateUrl: 'templates/event.html',
                        controller: 'EventCtrl'
                    }
                }
            });

        var DEFAULT_TIMEZONE = '+0000';

        $provide.decorator('dateFilter', ['$delegate', '$injector', function($delegate, $injector) {
            var oldDelegate = $delegate;

            var standardDateFilterInterceptor = function(date, format, timezone) {
                if(angular.isUndefined(timezone)) {
                    timezone = DEFAULT_TIMEZONE;
                }
                return oldDelegate.apply(this, [date, format, timezone]);
            };

            return standardDateFilterInterceptor;
        }]);

        $urlRouterProvider.otherwise('/app/events/upcoming');

        $translateProvider.translations('en', {
            // ------ START ---------------------------------
            start_welcome: "Welcome",
            start_welcome_description: "TAMK Events showcases all events held by student organizations and clubs.",
            start_filters: "Filters",
            start_filters_description: "Select all the organizers whose events interest you. " +
            "If you want to see all events, you don't have to select any filters. " +
            "You can always change the filters later.",
            start_ready: "All set",
            start_ready_description: "Browse or search events and add them to your favorites. You can also add events to your device's calendar!",
            start_ready_button: "Start the app",
            // ------ EVENTS --------------------------------
            events: "Events",
            upcoming: "Upcoming",
            latest: "Latest",
            favorites: "Favorites",
            load_more: "Load more events",
            no_events_title: "Nothing to see here",
            no_events_description: "We didn't find any events matching your filters. Please select more filters to see some events.",
            no_favorites: "Add events as favorites by tapping the star in the event's details.",
            no_events_search_title: "No results",
            no_events_search_description: "We didn't find any events matching your search.",
            search_placeholder: "Search from all events",
            // ------ FILTERS -------------------------------
            filter: "Filter events",
            organizations: "Student organizations and Tamko",
            clubs: "Clubs",
            tamks: "TAMK",
            partners: "Partners",
            tags: "Tags",
            save: "Save",
            select_organizations: "Select organizations",
            select_clubs: "Select clubs",
            select_tamks: "Select others",
            select_tags: "Select tags",
            select_partners: "Select partners",
            // ------ EVENT ---------------------------------
            back: "Back",
            private: "This event is only for members",
            date: "Date",
            starting_location: "Starting location",
            location: "Location",
            tickets: "Tickets",
            facebook: "Open event's Facebook page",
            add_calendar: " successfully added to calendar.",
            err_calendar: "Error: Could not save to calendar.",
            add_favorite: " added to favorites",
            copy: "Copied: ",
            // ------ SETTINGS ------------------------------
            language: "Language",
            change_language: "Suomeksi",
            // --------- MAP --------------------------------
            map: "Location",
            back_button: "Back",
            // --------- TICKET -----------------------------
            ticket_sales_start: "Sales start",
            ticket_price: "Ticket price",
            ticket_purchase: "Purchase ticket",
            // --------- AFTERPARTY -------------------------
            afterparty: "Afterparty"
        });

        $translateProvider.translations('fi', {
            // ------ START ---------------------------------
            start_welcome: "Tervetuloa",
            start_welcome_description: "TAMK Events näyttää sinulle kaikki Tampereen Ammattikorkeakoulun ainejärjestöjen ja kerhojen tapahtumat.",
            start_filters: "Suodattimet",
            start_filters_description: "Valitse ne ainejärjestöt ja kerhot, joiden tapahtumista olet kiinnostunut. " +
            "Jos olet kiinnostunut kaikista tapahtumista, älä lisää suodattimia. " +
            "Voit muuttaa suodattimia milloin tahansa.",
            start_ready: "Valmista",
            start_ready_description: "Selaile tai hae tapahtumia ja lisää kiinnostavimmat suosikkeihin. " +
            "Voit myös lisätä tapahtumia puhelimesi kalenteriin.",
            start_ready_button: "Aloita käyttö",
            // ------ EVENTS --------------------------------
            events: "Tapahtumat",
            upcoming: "Tulossa",
            latest: "Uusimmat",
            favorites: "Suosikit",
            load_more: "Lataa lisää tapahtumia",
            no_events_title: "Ei tapahtumia",
            no_events_description: "Emme löytäneet tapahtumia antamillasi suodattimilla. Ole hyvä ja poista suodattimia nähdäksesi tapahtumia.",
            no_favorites: "Lisää tapahtumia suosikkeihin painamalla tähteä tapahtuman tiedoissa.",
            no_events_search_title: "Ei hakutuloksia",
            no_events_search_description: "Emme löytäneet antamallasi hakusanalla ainuttakaan tapahtumaa.",
            search_placeholder: "Hae kaikista tapahtumista",
            // ------ FILTERS -------------------------------
            filter: "Suodata tapahtumia",
            organizations: "Ainejärjestöt ja Tamko",
            clubs: "Kerhot",
            tamks: "TAMK",
            partners: "Yhteistyökumppanit",
            tags: "Tagit",
            save: "Tallenna",
            select_organizations: "Valitse ainejärjestöt",
            select_clubs: "Valitse kerhot",
            select_tamks: "Valitse muut",
            select_tags: "Valitse tagit",
            select_partners: "Valitse yhteistyökumppanit",
            // ------ EVENT ---------------------------------
            back: "Takaisin",
            private: "Tämä tapahtuma on vain jäsenille",
            date: "Ajankohta",
            starting_location: "Lähtöpaikka",
            location: "Tapahtumapaikka",
            tickets: "Liput",
            facebook: "Avaa tapahtuman Facebook sivu",
            add_calendar: " lisätty puhelimen kalenteriin.",
            err_calendar: "Tapahtui virhe. Tapahtumaa ei tallennettu kalenteriin.",
            add_favorite: " lisätty suosikkeihin",
            copy: "Kopioitu: ",
            // ------ SETTINGS ------------------------------
            language: "Kieli",
            change_language: "In english",
            // --------- MAP --------------------------------
            map: "Sijainti",
            back_button: "Takaisin",
            // --------- TICKET -----------------------------
            ticket_sales_start: "Lipunmyynti alkaa",
            ticket_price: "Lipun hinta",
            ticket_purchase: "Osta lippu",
            // --------- AFTERPARTY -------------------------
            afterparty: "Jatkot"
        });

        if (!localStorage.language && navigator.language === "fi-FI") {
            $translateProvider.preferredLanguage('fi');
            localStorage.language = "fi";
        } else if (!localStorage.language && navigator.language !== "fi-FI") {
            $translateProvider.preferredLanguage('en');
            localStorage.language = "en";
        } else {
            $translateProvider.preferredLanguage(localStorage.language);
        }
    });
