angular.module('tamkEvents')

    .controller('AppCtrl',
        function ($scope, $ionicModal, $rootScope, $translate, $state,
                  $cordovaToast, $cordovaDevice, $ionicPlatform,
                  TagService, OrganizerService, $ionicScrollDelegate) {

            console.log("APP CONTROL INITIALIZATION");

            $rootScope.$on("http-error", function (event, err) {
                $cordovaToast.showLongBottom(err.statusText + ": " + err.data.message);
            });

            $rootScope.toggleSearch = function () {
                $rootScope.search.show = !$rootScope.search.show;
                $rootScope.search.term = "";
                if (!$rootScope.search.show) {
                    $rootScope.$broadcast("reload-events");
                } else {
                    $ionicScrollDelegate.scrollTop();
                }
            };

            $scope.$on("$ionicView.beforeEnter", function(event, data){
                $rootScope.state = {
                    name: data.stateId
                };

                $rootScope.$broadcast("reload-events");

                if ($rootScope.search.show) {
                    $rootScope.toggleSearch();
                }
            });

            $scope.changeLanguage = function () {
                if ($translate.proposedLanguage() === "fi") {
                    localStorage.language = "en";
                } else {
                    localStorage.language = "fi";
                }

                $translate.use(localStorage.language);

                $rootScope.$broadcast("reload-events");
            };

            $rootScope.filterCache = {};

            OrganizerService.getOrganizers(null, function (err, organizers) {
                if (!err) {
                    $rootScope.filterCache.organizers = organizers;
                }
            });

            TagService.getTags(function (err, tags) {
                if (!err) {
                    $rootScope.filterCache.tags = tags;
                }
            });

            fromStorage(["organizations", "clubs", "tags", "tamks", "partners"]);
            createModals(["organizations", "clubs", "tags", "tamks", "partners"]);

            function fromStorage(keys) {
                keys.forEach(function (key) {
                    $rootScope[key] = [];

                    if (localStorage[key]) {
                        $rootScope[key] = JSON.parse(localStorage[key]);
                    }
                });
            }

            function createModals(keys) {
                keys.forEach(function (key) {
                    $scope["choose" + key] = function () {
                        $ionicModal.fromTemplateUrl('templates/modals/' + key + '.html', function (modal) {
                            $scope[key + "Modal"] = modal;
                            $scope[key + "Modal"].show();

                            $rootScope.$on(key + "-saved", function () {
                                fromStorage([key]);
                                $scope[key + "Modal"].hide().then(function () {
                                    $rootScope.$broadcast("reload-events");
                                });
                            });
                        });
                    };
                });
            }

            $rootScope.$on("no-event", function () {
                $scope.customBack();
            });

            $scope.customBack = function () {
                if ($rootScope.fromEvent) {
                    $state.go($state.current.name, {id: $rootScope.fromEvent});
                    delete $rootScope.fromEvent;
                } else {
                    $state.go("app." + $state.current.name.split("app.")[1].split("event")[0]);
                }
            }
        })

    .component('eventCard', {
        templateUrl: 'templates/eventCard.html',
        controller: function () {
        },
        bindings: {
            event: "="
        }
    });
