angular.module('tamkEvents').controller('EventCtrl',
    function ($scope, $rootScope, $stateParams, EventService, $ionicLoading,
              $cordovaInAppBrowser, $state, $ionicTabsDelegate, $ionicHistory,
              $ionicModal, $cordovaCalendar, $cordovaToast, $translate,
              $cordovaClipboard, $cordovaVibration, $filter) {

        $scope.$on('$ionicView.beforeEnter', function (event, viewData) {
            viewData.enableBack = true;
        });

        $ionicTabsDelegate.showBar(false);
        $scope.event = {};
        var favorites;

        $ionicLoading.show({
            template: '<ion-spinner></ion-spinner>'
        });

        EventService.getEvent($state.params.id, function (err, result) {
            if (!err) {
                $scope.event = result;
                $rootScope.location = $scope.event.location;
                if ($scope.event.starting_location) {
                    $rootScope.starting_location = $scope.event.starting_location;
                }
            } else {
                $rootScope.$broadcast("no-event");
                console.log(err);
            }

            $ionicLoading.hide();
        });

        $scope.favoriteStar = false;
        getFavorites();

        $scope.openLink = function (link) {
            $ionicLoading.show({
                template: '<ion-spinner></ion-spinner>'
            });

            $cordovaInAppBrowser.open(link, "_system");

            setTimeout(function () {
                $ionicLoading.hide();
            }, 2000);
        };

        $scope.addToFavorite = function () {
            var id = $state.params.id;
            var alreadyFav = false;
            getFavorites();
            // Just in case checks that event is not already a favorite event.
            favorites.forEach(function (favId) {
                if (favId === id) {
                    alreadyFav = true;
                }
            });

            if (!alreadyFav) {
                favorites.push(id);
                $cordovaToast.showLongBottom($scope.event.name
                    + $translate.instant('add_favorite'));
            }

            localStorage.favorites = JSON.stringify(favorites);
            console.log(localStorage.favorites);
            $scope.favoriteStar = true;
            $rootScope.$broadcast("reload-events");
        };

        $scope.deleteFromFavorite = function () {
            var id = $state.params.id;
            getFavorites();
            favorites.forEach(function (favId, index) {
                if (favId === id) {
                    favorites.splice(index, 1);
                }
            });

            localStorage.favorites = JSON.stringify(favorites);
            console.log(localStorage.favorites);
            $scope.favoriteStar = false;
            $rootScope.$broadcast("reload-events");
        };

        function getFavorites() {
            if (localStorage.favorites === undefined ||
                localStorage.favorites === "" ||
                localStorage.favorites === "undefined") {
                favorites = [];
            } else {
                favorites = JSON.parse(localStorage.favorites);
            }

            favorites.forEach(function (favId) {
                if (favId === $state.params.id) {
                    $scope.favoriteStar = true;
                }
            })
        }

        $scope.createModal = function (name, type) {
            console.log(name);

            if (type) {
                $scope.locationType = type;
            }

            $ionicModal.fromTemplateUrl("templates/modals/" + name + ".html",
                {
                    scope: $scope,
                    animation: 'slide-in-up'
                }
            ).then(function (modal) {
                $scope.modal = modal;
                $scope.modal.show();

                $scope.$on("modal.hidden", function (event, data) {
                    data.remove();
                });
            });
        };

        $scope.closeModal = function () {
            $scope.modal.remove();
        };

        $scope.addToCalendar = function () {
            var start = new Date($scope.event.start_time);
            var end = new Date($scope.event.end_time);

            $cordovaCalendar.createEventInteractively({
                title: $scope.event.name,
                location: $scope.event.location.name,
                startDate: new Date(start.getFullYear(), start.getMonth(), start.getDate(), start.getHours(), start.getMinutes() + start.getTimezoneOffset(), 0),
                endDate: new Date(end.getFullYear(), end.getMonth(), end.getDate(), end.getHours(), end.getMinutes() + end.getTimezoneOffset(), 0)
            });
        };

        $scope.erika = function () {
            var start = moment($scope.event.start_time);
            var end = moment($scope.event.end_time);

            return end.diff(start, "hours") > 23;
        };

        $scope.openAfterparty = function () {
            if ($scope.event.afterparty.event_reference) {
                $scope.openEvent($scope.event.afterparty.event_reference);
            } else {
                $scope.createModal('afterparty', $scope.event.afterparty.location);
            }
        };

        $scope.openEvent = function (id) {
            $rootScope.fromEvent = $scope.event.id;
            $state.go($state.current.name, {id: id});
        };

        $scope.copyText = function (value) {
            $cordovaClipboard.copy(value).then(function () {
                $cordovaVibration.vibrate(100);
                $cordovaToast.showLongBottom($translate.instant('copy') + value);
            }, function () {
                $cordovaToast.showLongBottom("Error copying text");
            })
        };

        $scope.formatDate = function (startDate, endDate) {
            if (endDate) {
                return $filter('date')(startDate, "dd.MM.yyyy HH:mm") + " - "
                    + $filter('date')(endDate, "dd.MM.yyyy HH:mm");
            } else {
                return $filter('date')(startDate, "dd.MM.yyyy HH:mm");
            }
        };
    });