angular.module('tamkEvents').controller('EventsCtrl',
    function ($scope, $rootScope, $ionicModal, $ionicTabsDelegate, EventService,
              $state, $ionicScrollDelegate, $ionicPlatform, $ionicSideMenuDelegate) {

        $scope.$on('$ionicView.beforeEnter', function (event, viewData) {
            viewData.enableBack = false;
            $ionicTabsDelegate.showBar(true);
        });

        $rootScope.$on("reload-events", function () {
            $scope.loadEvents();
        });

        function getOrganizerFilter() {
            return $rootScope.organizations
                .concat($rootScope.clubs)
                .concat($rootScope.tamks)
                .concat($rootScope.partners)
                .join();
        }

        function getTagFilter() {
            return $rootScope.tags.join();
        }

        $rootScope.search = {
            term: "",
            show: false
        };

        $scope.events = [];
        $scope.loaded = 20;
        $scope.allowLoading = true;
        var stateName = $state.current.name.split("app.")[1];

        $scope.loadEvents = function () {
            $ionicPlatform.ready(function () {
                cordova.plugins.Keyboard.close();
            });

            var options;

            switch (stateName) {
                case "favorites":
                    if (localStorage.favorites) {
                        options = {
                            ids: JSON.parse(localStorage.favorites)
                        };
                    } else {
                        options = {
                            ids: [0]
                        }
                    }
                    break;

                default:
                    options = {
                        limit: $scope.loaded,
                        order: stateName,
                        organizers: getOrganizerFilter(),
                        tags: getTagFilter()
                    };
                    break;
            }

            if ($rootScope.search.term && $rootScope.search.show) {
                console.log("doing more");
                options.search = $rootScope.search.term;
                options.order = "relevance";
                delete options.organizers;
                delete options.tags;
            }

            $scope.loadingEvents = true;
            EventService.getEvents(options, function (err, result) {
                if (!err) {
                    if (result.length < $scope.loaded) {
                        $scope.allowLoading = false;
                    }

                    $scope.events = result;
                } else {
                    console.log(err.data.message);
                }

                $scope.$broadcast('scroll.refreshComplete');

                $ionicScrollDelegate.resize();
                $scope.loadingEvents = false;
            });
        };

        $scope.loadMore = function () {
            $scope.loaded += 20;
            $scope.loadEvents();
        };

        $ionicModal.fromTemplateUrl('templates/event.html', function (modal) {
            $scope.eventModal = modal;
        }, {
            scope: $scope,
            animation: 'slide-in-left'
        });

        $scope.closeEvent = function () {
            $scope.eventModal.hide();
        };

        $scope.viewEvent = function (id) {
            console.log(id);
            console.log("navigating to " + $state.current.name + "event");
            delete $rootScope.fromEvent;
            $state.go($state.current.name + "event", {id: id});
        };

        $scope.loadEvents();

        $scope.nextTab = function () {
            var selected = $ionicTabsDelegate.selectedIndex();
            if (selected === 0) {
                location.href="#/app/events/latest";
            } else if (selected === 1) {
                location.href="#/app/events/favorites";
            }
        };

        $scope.previousTab = function () {
            var selected = $ionicTabsDelegate.selectedIndex();
            if (selected === 2) {
                location.href="#/app/events/latest";
            } else if (selected === 1) {
                location.href="#/app/events/upcoming";
            }
        }
    });
